@@ -1,18 +1,10 @@
+package App::ClusterSSH::Helper;
+
 use strict;
 use warnings;
 
-package App::ClusterSSH::Helper;
-$App::ClusterSSH::Helper::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Helper::VERSION = '4.1806';
-# ABSTRACT: ClusterSSH::Helper - Object representing helper script
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Object representing application configuration
-
-=cut
+use version;
+our $VERSION = version->new('0.02');
 
 use Carp;
 use Try::Tiny;
@@ -53,8 +45,6 @@ sub script {
         }
     }
 
-    my $command_pre    = $config->{command_pre}  || q{};
-    my $command_post   = $config->{command_post} || q{};
     my $comms          = $config->{ $config->{comms} };
     my $comms_args     = $config->{ $config->{comms} . '_args' };
     my $config_command = $config->{command};
@@ -72,9 +62,9 @@ sub script {
            my \$user=shift;
            my \$port=shift;
            my \$mstr=shift;
-           my \$command="$command_pre $comms $comms_args ";
+           my \$command="$comms $comms_args ";
            open(PIPE, ">", \$pipe) or die("Failed to open pipe: \$!\\n");
-           print PIPE "\$\$:\$ENV{WINDOWID}"
+           print PIPE "\$\$:\$ENV{WINDOWID}" 
                or die("Failed to write to pipe: $!\\n");
            close(PIPE) or die("Failed to close pipe: $!\\n");
            if(\$svr =~ m/==\$/)
@@ -108,10 +98,8 @@ sub script {
            if("$config_command") {
             \$command .= " \\\"$config_command\\\"";
            }
-           \$command .= "$command_post";
            \$command .= " ; $postcommand";
-           # provide some info for debugging purposes
-           warn("Running: \$command\\n");
+           warn("Running:\$command\\n"); # for debug purposes
            exec(\$command);
     HERE
 
@@ -131,6 +119,18 @@ sub script {
 
 1;
 
+=pod
+
+=head1 NAME
+
+ClusterSSH::Helper - Object representing helper script
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Object representing application configuration
+
 =head1 METHODS
 
 =over 4
@@ -144,3 +144,21 @@ Create a new helper object.
 Return the helper script
 
 =back
+
+=head1 AUTHOR
+
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 1999-2015 Duncan Ferguson.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
